msm: 8974: rename copper to 8974
The official name for copper is MSM8974.
Switch to it.
Change-Id: Ifb241232111139912477bf7b5f2e9cf5d38d0f9e
Signed-off-by: Abhimanyu Kapur <abhimany@codeaurora.org>
diff --git a/arch/arm/boot/dts/msmcopper-gpio.dtsi b/arch/arm/boot/dts/msm8974-gpio.dtsi
similarity index 100%
rename from arch/arm/boot/dts/msmcopper-gpio.dtsi
rename to arch/arm/boot/dts/msm8974-gpio.dtsi
diff --git a/arch/arm/boot/dts/msmcopper-iommu.dtsi b/arch/arm/boot/dts/msm8974-iommu.dtsi
similarity index 100%
rename from arch/arm/boot/dts/msmcopper-iommu.dtsi
rename to arch/arm/boot/dts/msm8974-iommu.dtsi
diff --git a/arch/arm/boot/dts/msmcopper-regulator.dtsi b/arch/arm/boot/dts/msm8974-regulator.dtsi
similarity index 100%
rename from arch/arm/boot/dts/msmcopper-regulator.dtsi
rename to arch/arm/boot/dts/msm8974-regulator.dtsi
diff --git a/arch/arm/boot/dts/msmcopper-rumi.dts b/arch/arm/boot/dts/msm8974-rumi.dts
similarity index 94%
rename from arch/arm/boot/dts/msmcopper-rumi.dts
rename to arch/arm/boot/dts/msm8974-rumi.dts
index 3f1a2ac..b179d94 100644
--- a/arch/arm/boot/dts/msmcopper-rumi.dts
+++ b/arch/arm/boot/dts/msm8974-rumi.dts
@@ -12,11 +12,11 @@
/dts-v1/;
-/include/ "msmcopper.dtsi"
+/include/ "msm8974.dtsi"
/ {
- model = "Qualcomm MSM Copper RUMI";
- compatible = "qcom,msmcopper-rumi", "qcom,msmcopper";
+ model = "Qualcomm MSM 8974 RUMI";
+ compatible = "qcom,msm8974-rumi", "qcom,msm8974";
timer {
clock-frequency = <5000000>;
diff --git a/arch/arm/boot/dts/msmcopper-sim.dts b/arch/arm/boot/dts/msm8974-sim.dts
similarity index 81%
rename from arch/arm/boot/dts/msmcopper-sim.dts
rename to arch/arm/boot/dts/msm8974-sim.dts
index ab6b8ba..b6044a6 100644
--- a/arch/arm/boot/dts/msmcopper-sim.dts
+++ b/arch/arm/boot/dts/msm8974-sim.dts
@@ -12,9 +12,9 @@
/dts-v1/;
-/include/ "msmcopper.dtsi"
+/include/ "msm8974.dtsi"
/ {
- model = "Qualcomm MSM Copper Simulator";
- compatible = "qcom,msmcopper-sim", "qcom,msmcopper";
+ model = "Qualcomm MSM 8974 Simulator";
+ compatible = "qcom,msm8974-sim", "qcom,msm8974";
};
diff --git a/arch/arm/boot/dts/msmcopper.dtsi b/arch/arm/boot/dts/msm8974.dtsi
similarity index 97%
rename from arch/arm/boot/dts/msmcopper.dtsi
rename to arch/arm/boot/dts/msm8974.dtsi
index bc7c5f0..dbc9161 100644
--- a/arch/arm/boot/dts/msmcopper.dtsi
+++ b/arch/arm/boot/dts/msm8974.dtsi
@@ -11,18 +11,18 @@
*/
/include/ "skeleton.dtsi"
-/include/ "msmcopper_pm.dtsi"
+/include/ "msm8974_pm.dtsi"
/include/ "msm-pm8x41-rpm-regulator.dtsi"
/include/ "msm-pm8841.dtsi"
/include/ "msm-pm8941.dtsi"
-/include/ "msmcopper-regulator.dtsi"
-/include/ "msmcopper-gpio.dtsi"
-/include/ "msmcopper-iommu.dtsi"
+/include/ "msm8974-regulator.dtsi"
+/include/ "msm8974-gpio.dtsi"
+/include/ "msm8974-iommu.dtsi"
/include/ "msm-gdsc.dtsi"
/ {
- model = "Qualcomm MSM Copper";
- compatible = "qcom,msmcopper";
+ model = "Qualcomm MSM 8974";
+ compatible = "qcom,msm8974";
interrupt-parent = <&intc>;
intc: interrupt-controller@F9000000 {
@@ -269,7 +269,7 @@
};
qcom,acpuclk@f9000000 {
- compatible = "qcom,acpuclk-copper";
+ compatible = "qcom,acpuclk-8974";
krait0-supply = <&krait0_vreg>;
krait1-supply = <&krait1_vreg>;
krait2-supply = <&krait2_vreg>;
diff --git a/arch/arm/boot/dts/msmcopper_pm.dtsi b/arch/arm/boot/dts/msm8974_pm.dtsi
similarity index 100%
rename from arch/arm/boot/dts/msmcopper_pm.dtsi
rename to arch/arm/boot/dts/msm8974_pm.dtsi
diff --git a/arch/arm/configs/msm-copper_defconfig b/arch/arm/configs/msm8974_defconfig
similarity index 99%
rename from arch/arm/configs/msm-copper_defconfig
rename to arch/arm/configs/msm8974_defconfig
index 57cd263..465cd8e 100644
--- a/arch/arm/configs/msm-copper_defconfig
+++ b/arch/arm/configs/msm8974_defconfig
@@ -31,7 +31,7 @@
CONFIG_PARTITION_ADVANCED=y
CONFIG_EFI_PARTITION=y
CONFIG_ARCH_MSM=y
-CONFIG_ARCH_MSMCOPPER=y
+CONFIG_ARCH_MSM8974=y
CONFIG_MSM_KRAIT_TBB_ABORT_HANDLER=y
# CONFIG_MSM_STACKED_MEMORY is not set
CONFIG_KERNEL_PMEM_EBI_REGION=y
diff --git a/arch/arm/mach-msm/Kconfig b/arch/arm/mach-msm/Kconfig
index 776bf40..27f72e0 100644
--- a/arch/arm/mach-msm/Kconfig
+++ b/arch/arm/mach-msm/Kconfig
@@ -225,8 +225,8 @@
select MIGHT_HAVE_PCI
select ARCH_SUPPORTS_MSI
-config ARCH_MSMCOPPER
- bool "MSM Copper"
+config ARCH_MSM8974
+ bool "MSM8974"
select ARCH_MSM_KRAITMP
select GPIO_MSM_V3
select ARM_GIC
@@ -877,7 +877,7 @@
default "0x80200000" if ARCH_APQ8064
default "0x80200000" if ARCH_MSM8960
default "0x80200000" if ARCH_MSM8930
- default "0x00000000" if ARCH_MSMCOPPER
+ default "0x00000000" if ARCH_MSM8974
default "0x10000000" if ARCH_FSM9XXX
default "0x20200000" if ARCH_MSM9625
default "0x00200000" if !MSM_STACKED_MEMORY
@@ -889,7 +889,7 @@
config KERNEL_PMEM_EBI_REGION
bool "Enable in-kernel PMEM region for EBI"
default y if ARCH_MSM8X60
- depends on ANDROID_PMEM && (ARCH_MSM8X60 || ARCH_MSM8960 || ARCH_MSMCOPPER)
+ depends on ANDROID_PMEM && (ARCH_MSM8X60 || ARCH_MSM8960 || ARCH_MSM8974)
help
Enable the in-kernel PMEM allocator to use EBI memory.
@@ -1007,13 +1007,13 @@
Say Y here if you want the debug print routines to direct
their output to the serial port on APQ 8064 devices.
- config DEBUG_MSMCOPPER_UART
- bool "Kernel low-level debugging messages via MSM Copper UART"
- depends on ARCH_MSMCOPPER
+ config DEBUG_MSM8974_UART
+ bool "Kernel low-level debugging messages via MSM 8974 UART"
+ depends on ARCH_MSM8974
select MSM_HAS_DEBUG_UART_HS_V14
help
Say Y here if you want the debug print routines to direct
- their output to the serial port on MSM Copper devices.
+ their output to the serial port on MSM 8974 devices.
endchoice
choice
diff --git a/arch/arm/mach-msm/Makefile b/arch/arm/mach-msm/Makefile
index ec8de9f..dc9234b 100644
--- a/arch/arm/mach-msm/Makefile
+++ b/arch/arm/mach-msm/Makefile
@@ -99,7 +99,7 @@
ifndef CONFIG_ARCH_APQ8064
ifndef CONFIG_ARCH_MSM8960
ifndef CONFIG_ARCH_MSM8X60
-ifndef CONFIG_ARCH_MSMCOPPER
+ifndef CONFIG_ARCH_MSM8974
obj-$(CONFIG_MSM_SMD) += pmic.o
obj-$(CONFIG_MSM_ONCRPCROUTER) += rpc_hsusb.o rpc_pmapp.o rpc_fsusb.o
endif
@@ -110,7 +110,7 @@
ifndef CONFIG_ARCH_MSM8960
ifndef CONFIG_ARCH_MSM8X60
ifndef CONFIG_ARCH_APQ8064
-ifndef CONFIG_ARCH_MSMCOPPER
+ifndef CONFIG_ARCH_MSM8974
ifndef CONFIG_ARCH_MSM9625
obj-y += nand_partitions.o
endif
@@ -212,7 +212,7 @@
obj-$(CONFIG_ARCH_MSM8960) += cpuidle.o
obj-$(CONFIG_ARCH_MSM8X60) += cpuidle.o
obj-$(CONFIG_ARCH_MSM9615) += cpuidle.o
- obj-$(CONFIG_ARCH_MSMCOPPER) += cpuidle.o
+ obj-$(CONFIG_ARCH_MSM8974) += cpuidle.o
endif
ifdef CONFIG_MSM_CAMERA_V4L2
@@ -287,10 +287,10 @@
obj-$(CONFIG_MACH_MPQ8064_DTV) += board-8064-all.o board-8064-regulator.o
obj-$(CONFIG_ARCH_MSM9615) += board-9615.o devices-9615.o board-9615-regulator.o board-9615-gpiomux.o board-9615-storage.o board-9615-display.o
obj-$(CONFIG_ARCH_MSM9615) += clock-local.o clock-9615.o acpuclock-9615.o clock-rpm.o clock-pll.o
-obj-$(CONFIG_ARCH_MSMCOPPER) += board-copper.o board-dt.o board-copper-regulator.o board-copper-gpiomux.o
-obj-$(CONFIG_ARCH_MSMCOPPER) += acpuclock-krait.o acpuclock-copper.o
-obj-$(CONFIG_ARCH_MSMCOPPER) += clock-local2.o clock-pll.o clock-copper.o clock-rpm.o clock-voter.o
-obj-$(CONFIG_ARCH_MSMCOPPER) += gdsc.o
+obj-$(CONFIG_ARCH_MSM8974) += board-8974.o board-dt.o board-8974-regulator.o board-8974-gpiomux.o
+obj-$(CONFIG_ARCH_MSM8974) += acpuclock-krait.o acpuclock-8974.o
+obj-$(CONFIG_ARCH_MSM8974) += clock-local2.o clock-pll.o clock-8974.o clock-rpm.o clock-voter.o
+obj-$(CONFIG_ARCH_MSM8974) += gdsc.o
obj-$(CONFIG_ARCH_MSM9625) += board-9625.o board-9625-gpiomux.o
obj-$(CONFIG_MACH_SAPPHIRE) += board-sapphire.o board-sapphire-gpio.o
@@ -316,7 +316,7 @@
obj-$(CONFIG_ARCH_MSM9615) += rpm_resources.o
endif
ifdef CONFIG_MSM_RPM_SMD
- obj-$(CONFIG_ARCH_MSMCOPPER) += lpm_levels.o lpm_resources.o
+ obj-$(CONFIG_ARCH_MSM8974) += lpm_levels.o lpm_resources.o
endif
obj-$(CONFIG_MSM_MPM) += mpm.o
obj-$(CONFIG_MSM_RPM_STATS_LOG) += rpm_stats.o
@@ -341,7 +341,7 @@
obj-$(CONFIG_ARCH_MSM8960) += gpiomux-v2.o gpiomux.o
obj-$(CONFIG_ARCH_APQ8064) += gpiomux-v2.o gpiomux.o
obj-$(CONFIG_ARCH_MSM9615) += gpiomux-v2.o gpiomux.o
-obj-$(CONFIG_ARCH_MSMCOPPER) += gpiomux-v2.o gpiomux.o
+obj-$(CONFIG_ARCH_MSM8974) += gpiomux-v2.o gpiomux.o
obj-$(CONFIG_ARCH_MSM9625) += gpiomux-v2.o gpiomux.o
diff --git a/arch/arm/mach-msm/Makefile.boot b/arch/arm/mach-msm/Makefile.boot
index bd8d153..b57d4e1 100644
--- a/arch/arm/mach-msm/Makefile.boot
+++ b/arch/arm/mach-msm/Makefile.boot
@@ -45,8 +45,8 @@
# APQ8064
zreladdr-$(CONFIG_ARCH_APQ8064) := 0x80208000
-# MSMCOPPER
- zreladdr-$(CONFIG_ARCH_MSMCOPPER) := 0x00008000
+# MSM8974
+ zreladdr-$(CONFIG_ARCH_MSM8974) := 0x00008000
# MSM9615
zreladdr-$(CONFIG_ARCH_MSM9615) := 0x40808000
diff --git a/arch/arm/mach-msm/board-copper-gpiomux.c b/arch/arm/mach-msm/board-8974-gpiomux.c
similarity index 96%
rename from arch/arm/mach-msm/board-copper-gpiomux.c
rename to arch/arm/mach-msm/board-8974-gpiomux.c
index caba698..6fcc779 100644
--- a/arch/arm/mach-msm/board-copper-gpiomux.c
+++ b/arch/arm/mach-msm/board-8974-gpiomux.c
@@ -114,13 +114,13 @@
},
};
-void __init msm_copper_init_gpiomux(void)
+void __init msm_8974_init_gpiomux(void)
{
int rc;
rc = msm_gpiomux_init(NR_GPIO_IRQS);
if (rc) {
- pr_err(KERN_ERR "msmcopper_init_gpiomux failed %d\n", rc);
+ pr_err(KERN_ERR "msm_8974_init_gpiomux failed %d\n", rc);
return;
}
diff --git a/arch/arm/mach-msm/board-copper-regulator.c b/arch/arm/mach-msm/board-8974-regulator.c
similarity index 80%
rename from arch/arm/mach-msm/board-copper-regulator.c
rename to arch/arm/mach-msm/board-8974-regulator.c
index 10d5d0b..1a41f09 100644
--- a/arch/arm/mach-msm/board-copper-regulator.c
+++ b/arch/arm/mach-msm/board-8974-regulator.c
@@ -71,25 +71,25 @@
KRAIT_PWR(K2, "krait2", 0, 850000, 1100000, NULL, 100000, 0);
KRAIT_PWR(K3, "krait3", 0, 850000, 1100000, NULL, 100000, 0);
-#define VREG_DEVICE(_name, _devid) \
- vreg_device_##_name __devinitdata = \
- { \
- .name = STUB_REGULATOR_DRIVER_NAME, \
- .id = _devid, \
- .dev = { .platform_data = &vreg_dev_##_name##_pdata }, \
- }
+#define VREG_DEVICE(_name, _devid) \
+ static struct platform_device vreg_device_##_name __devinitdata = \
+ { \
+ .name = STUB_REGULATOR_DRIVER_NAME, \
+ .id = _devid, \
+ .dev = { .platform_data = &vreg_dev_##_name##_pdata }, \
+ }
-static struct platform_device VREG_DEVICE(K0, 0);
-static struct platform_device VREG_DEVICE(K1, 1);
-static struct platform_device VREG_DEVICE(K2, 2);
-static struct platform_device VREG_DEVICE(K3, 3);
+VREG_DEVICE(K0, 0);
+VREG_DEVICE(K1, 1);
+VREG_DEVICE(K2, 2);
+VREG_DEVICE(K3, 3);
-struct platform_device *msm_copper_stub_regulator_devices[] __devinitdata = {
+struct platform_device *msm_8974_stub_regulator_devices[] __devinitdata = {
&vreg_device_K0,
&vreg_device_K1,
&vreg_device_K2,
&vreg_device_K3,
};
-int msm_copper_stub_regulator_devices_len __devinitdata =
- ARRAY_SIZE(msm_copper_stub_regulator_devices);
+int msm_8974_stub_regulator_devices_len __devinitdata =
+ ARRAY_SIZE(msm_8974_stub_regulator_devices);
diff --git a/arch/arm/mach-msm/board-copper.c b/arch/arm/mach-msm/board-8974.c
similarity index 85%
rename from arch/arm/mach-msm/board-copper.c
rename to arch/arm/mach-msm/board-8974.c
index 2c5512a..4e881df 100644
--- a/arch/arm/mach-msm/board-copper.c
+++ b/arch/arm/mach-msm/board-8974.c
@@ -73,7 +73,7 @@
early_param("kernel_ebi1_mem_size", kernel_ebi1_mem_size_setup);
#endif
-static struct memtype_reserve msm_copper_reserve_table[] __initdata = {
+static struct memtype_reserve msm_8974_reserve_table[] __initdata = {
[MEMTYPE_SMI] = {
},
[MEMTYPE_EBI0] = {
@@ -84,7 +84,7 @@
},
};
-static int msm_copper_paddr_to_memtype(unsigned int paddr)
+static int msm_8974_paddr_to_memtype(unsigned int paddr)
{
return MEMTYPE_EBI1;
}
@@ -193,14 +193,14 @@
static void __init reserve_ion_memory(void)
{
- msm_copper_reserve_table[MEMTYPE_EBI1].size += MSM_ION_MM_SIZE;
- msm_copper_reserve_table[MEMTYPE_EBI1].size += MSM_ION_MM_FW_SIZE;
- msm_copper_reserve_table[MEMTYPE_EBI1].size += MSM_ION_SF_SIZE;
- msm_copper_reserve_table[MEMTYPE_EBI1].size += MSM_ION_MFC_SIZE;
- msm_copper_reserve_table[MEMTYPE_EBI1].size += MSM_ION_QSECOM_SIZE;
- msm_copper_reserve_table[MEMTYPE_EBI1].size += MSM_ION_AUDIO_SIZE;
+ msm_8974_reserve_table[MEMTYPE_EBI1].size += MSM_ION_MM_SIZE;
+ msm_8974_reserve_table[MEMTYPE_EBI1].size += MSM_ION_MM_FW_SIZE;
+ msm_8974_reserve_table[MEMTYPE_EBI1].size += MSM_ION_SF_SIZE;
+ msm_8974_reserve_table[MEMTYPE_EBI1].size += MSM_ION_MFC_SIZE;
+ msm_8974_reserve_table[MEMTYPE_EBI1].size += MSM_ION_QSECOM_SIZE;
+ msm_8974_reserve_table[MEMTYPE_EBI1].size += MSM_ION_AUDIO_SIZE;
#ifdef CONFIG_KERNEL_PMEM_EBI_REGION
- msm_copper_reserve_table[MEMTYPE_EBI1].size += kernel_ebi1_mem_size;
+ msm_8974_reserve_table[MEMTYPE_EBI1].size += kernel_ebi1_mem_size;
#endif
}
#endif
@@ -357,7 +357,7 @@
.smd_smem_areas = aux_smem_areas,
};
-struct platform_device msm_device_smd_copper = {
+struct platform_device msm_device_smd_8974 = {
.name = "msm_smd",
.id = -1,
.resource = smd_resource,
@@ -367,25 +367,25 @@
}
};
-static void __init msm_copper_calculate_reserve_sizes(void)
+static void __init msm_8974_calculate_reserve_sizes(void)
{
#ifdef CONFIG_ION_MSM
reserve_ion_memory();
#endif
}
-static struct reserve_info msm_copper_reserve_info __initdata = {
- .memtype_reserve_table = msm_copper_reserve_table,
- .calculate_reserve_sizes = msm_copper_calculate_reserve_sizes,
- .paddr_to_memtype = msm_copper_paddr_to_memtype,
+static struct reserve_info msm_8974_reserve_info __initdata = {
+ .memtype_reserve_table = msm_8974_reserve_table,
+ .calculate_reserve_sizes = msm_8974_calculate_reserve_sizes,
+ .paddr_to_memtype = msm_8974_paddr_to_memtype,
};
-static void __init msm_copper_early_memory(void)
+static void __init msm_8974_early_memory(void)
{
- reserve_info = &msm_copper_reserve_info;
+ reserve_info = &msm_8974_reserve_info;
}
-void __init msm_copper_reserve(void)
+void __init msm_8974_reserve(void)
{
msm_reserve();
}
@@ -396,7 +396,7 @@
};
#define SHARED_IMEM_TZ_BASE 0xFE805720
-static struct resource copper_tzlog_resources[] = {
+static struct resource msm8974_tzlog_resources[] = {
{
.start = SHARED_IMEM_TZ_BASE,
.end = SHARED_IMEM_TZ_BASE + SZ_4K - 1,
@@ -404,11 +404,11 @@
},
};
-struct platform_device copper_device_tz_log = {
+struct platform_device msm8974_device_tz_log = {
.name = "tz_log",
.id = 0,
- .num_resources = ARRAY_SIZE(copper_tzlog_resources),
- .resource = copper_tzlog_resources,
+ .num_resources = ARRAY_SIZE(msm8974_tzlog_resources),
+ .resource = msm8974_tzlog_resources,
};
#define BIMC_BASE 0xfc380000
@@ -521,7 +521,7 @@
.id = MSM_BUS_FAB_OCMEM_VNOC,
};
-static struct platform_device *msm_bus_copper_devices[] = {
+static struct platform_device *msm_bus_8974_devices[] = {
&msm_bus_sys_noc,
&msm_bus_bimc,
&msm_bus_mmss_noc,
@@ -531,32 +531,32 @@
&msm_bus_ocmem_vnoc,
};
-static void __init msmcopper_init_buses(void)
+static void __init msm8974_init_buses(void)
{
#ifdef CONFIG_MSM_BUS_SCALING
msm_bus_sys_noc.dev.platform_data =
- &msm_bus_copper_sys_noc_pdata;
- msm_bus_bimc.dev.platform_data = &msm_bus_copper_bimc_pdata;
- msm_bus_mmss_noc.dev.platform_data = &msm_bus_copper_mmss_noc_pdata;
- msm_bus_ocmem_noc.dev.platform_data = &msm_bus_copper_ocmem_noc_pdata;
- msm_bus_periph_noc.dev.platform_data = &msm_bus_copper_periph_noc_pdata;
- msm_bus_config_noc.dev.platform_data = &msm_bus_copper_config_noc_pdata;
- msm_bus_ocmem_vnoc.dev.platform_data = &msm_bus_copper_ocmem_vnoc_pdata;
+ &msm_bus_8974_sys_noc_pdata;
+ msm_bus_bimc.dev.platform_data = &msm_bus_8974_bimc_pdata;
+ msm_bus_mmss_noc.dev.platform_data = &msm_bus_8974_mmss_noc_pdata;
+ msm_bus_ocmem_noc.dev.platform_data = &msm_bus_8974_ocmem_noc_pdata;
+ msm_bus_periph_noc.dev.platform_data = &msm_bus_8974_periph_noc_pdata;
+ msm_bus_config_noc.dev.platform_data = &msm_bus_8974_config_noc_pdata;
+ msm_bus_ocmem_vnoc.dev.platform_data = &msm_bus_8974_ocmem_vnoc_pdata;
#endif
- platform_add_devices(msm_bus_copper_devices,
- ARRAY_SIZE(msm_bus_copper_devices));
+ platform_add_devices(msm_bus_8974_devices,
+ ARRAY_SIZE(msm_bus_8974_devices));
};
-void __init msm_copper_add_devices(void)
+void __init msm_8974_add_devices(void)
{
#ifdef CONFIG_ION_MSM
platform_device_register(&ion_dev);
#endif
- platform_device_register(&msm_device_smd_copper);
+ platform_device_register(&msm_device_smd_8974);
platform_device_register(&android_usb_device);
- platform_add_devices(msm_copper_stub_regulator_devices,
- msm_copper_stub_regulator_devices_len);
- platform_device_register(&copper_device_tz_log);
+ platform_add_devices(msm_8974_stub_regulator_devices,
+ msm_8974_stub_regulator_devices_len);
+ platform_device_register(&msm8974_device_tz_log);
}
static struct clk_lookup msm_clocks_dummy[] = {
@@ -599,7 +599,7 @@
* into this category, and thus the driver should not be added here. The
* EPROBE_DEFER can satisfy most dependency problems.
*/
-void __init msm_copper_add_drivers(void)
+void __init msm_8974_add_drivers(void)
{
msm_init_modem_notifier_list();
msm_smd_init();
@@ -608,11 +608,11 @@
rpm_regulator_smd_driver_init();
msm_spm_device_init();
regulator_stub_init();
- if (machine_is_copper_rumi())
+ if (machine_is_msm8974_rumi())
msm_clock_init(&msm_dummy_clock_init_data);
else
- msm_clock_init(&msmcopper_clock_init_data);
- msmcopper_init_buses();
+ msm_clock_init(&msm8974_clock_init_data);
+ msm8974_init_buses();
}
static struct of_device_id irq_match[] __initdata = {
@@ -622,12 +622,12 @@
{}
};
-void __init msm_copper_init_irq(void)
+void __init msm_8974_init_irq(void)
{
of_irq_init(irq_match);
}
-static struct of_dev_auxdata msm_copper_auxdata_lookup[] __initdata = {
+static struct of_dev_auxdata msm_8974_auxdata_lookup[] __initdata = {
OF_DEV_AUXDATA("qcom,msm-lsuart-v14", 0xF991F000, \
"msm_serial_hsl.0", NULL),
OF_DEV_AUXDATA("qcom,hsusb-otg", 0xF9A55000, \
@@ -660,16 +660,16 @@
{}
};
-void __init msm_copper_init(struct of_dev_auxdata **adata)
+void __init msm_8974_init(struct of_dev_auxdata **adata)
{
- msm_copper_init_gpiomux();
+ msm_8974_init_gpiomux();
- *adata = msm_copper_auxdata_lookup;
+ *adata = msm_8974_auxdata_lookup;
regulator_has_full_constraints();
}
-void __init msm_copper_very_early(void)
+void __init msm_8974_very_early(void)
{
- msm_copper_early_memory();
+ msm_8974_early_memory();
}
diff --git a/arch/arm/mach-msm/board-dt.c b/arch/arm/mach-msm/board-dt.c
index 8a801c2..b2a4ce2 100644
--- a/arch/arm/mach-msm/board-dt.c
+++ b/arch/arm/mach-msm/board-dt.c
@@ -35,14 +35,14 @@
static void __init msm_dt_init_irq(void)
{
- if (machine_is_copper())
- msm_copper_init_irq();
+ if (machine_is_msm8974())
+ msm_8974_init_irq();
}
static void __init msm_dt_map_io(void)
{
- if (early_machine_is_copper())
- msm_map_copper_io();
+ if (early_machine_is_msm8974())
+ msm_map_8974_io();
if (socinfo_init() < 0)
pr_err("%s: socinfo_init() failed\n", __func__);
}
@@ -51,31 +51,31 @@
{
struct of_dev_auxdata *adata = NULL;
- if (machine_is_copper())
- msm_copper_init(&adata);
+ if (machine_is_msm8974())
+ msm_8974_init(&adata);
of_platform_populate(NULL, of_default_bus_match_table, adata, NULL);
- if (machine_is_copper()) {
- msm_copper_add_devices();
- msm_copper_add_drivers();
+ if (machine_is_msm8974()) {
+ msm_8974_add_devices();
+ msm_8974_add_drivers();
}
}
static const char *msm_dt_match[] __initconst = {
- "qcom,msmcopper",
+ "qcom,msm8974",
NULL
};
static void __init msm_dt_reserve(void)
{
- if (early_machine_is_copper())
- msm_copper_reserve();
+ if (early_machine_is_msm8974())
+ msm_8974_reserve();
}
static void __init msm_dt_init_very_early(void)
{
- if (early_machine_is_copper())
- msm_copper_very_early();
+ if (early_machine_is_msm8974())
+ msm_8974_very_early();
}
DT_MACHINE_START(MSM_DT, "Qualcomm MSM (Flattened Device Tree)")
diff --git a/arch/arm/mach-msm/clock-copper.c b/arch/arm/mach-msm/clock-8974.c
similarity index 99%
rename from arch/arm/mach-msm/clock-copper.c
rename to arch/arm/mach-msm/clock-8974.c
index fcb69f0..5c7cddd 100644
--- a/arch/arm/mach-msm/clock-copper.c
+++ b/arch/arm/mach-msm/clock-8974.c
@@ -4577,7 +4577,7 @@
.multiplier = 1,
};
-static struct clk_lookup msm_clocks_copper[] = {
+static struct clk_lookup msm_clocks_8974[] = {
CLK_LOOKUP("xo", cxo_clk_src.c, "msm_otg"),
CLK_LOOKUP("xo", cxo_clk_src.c, "pil-q6v5-lpass"),
CLK_LOOKUP("xo", cxo_clk_src.c, "pil-q6v5-mss"),
@@ -5014,7 +5014,7 @@
writel_relaxed(0x0, GCC_REG_BASE(APCS_CLOCK_SLEEP_ENA_VOTE));
}
-static void __init msmcopper_clock_post_init(void)
+static void __init msm8974_clock_post_init(void)
{
clk_set_rate(&axi_clk_src.c, 333330000);
clk_set_rate(&ocmemnoc_clk_src.c, 333330000);
@@ -5060,32 +5060,32 @@
#define MSS_CC_PHYS 0xFC980000
#define MSS_CC_SIZE SZ_16K
-static void __init msmcopper_clock_pre_init(void)
+static void __init msm8974_clock_pre_init(void)
{
virt_bases[GCC_BASE] = ioremap(GCC_CC_PHYS, GCC_CC_SIZE);
if (!virt_bases[GCC_BASE])
- panic("clock-copper: Unable to ioremap GCC memory!");
+ panic("clock-8974: Unable to ioremap GCC memory!");
virt_bases[MMSS_BASE] = ioremap(MMSS_CC_PHYS, MMSS_CC_SIZE);
if (!virt_bases[MMSS_BASE])
- panic("clock-copper: Unable to ioremap MMSS_CC memory!");
+ panic("clock-8974: Unable to ioremap MMSS_CC memory!");
virt_bases[LPASS_BASE] = ioremap(LPASS_CC_PHYS, LPASS_CC_SIZE);
if (!virt_bases[LPASS_BASE])
- panic("clock-copper: Unable to ioremap LPASS_CC memory!");
+ panic("clock-8974: Unable to ioremap LPASS_CC memory!");
virt_bases[MSS_BASE] = ioremap(MSS_CC_PHYS, MSS_CC_SIZE);
if (!virt_bases[MSS_BASE])
- panic("clock-copper: Unable to ioremap MSS_CC memory!");
+ panic("clock-8974: Unable to ioremap MSS_CC memory!");
- clk_ops_local_pll.enable = copper_pll_clk_enable;
+ clk_ops_local_pll.enable = msm8974_pll_clk_enable;
reg_init();
}
-struct clock_init_data msmcopper_clock_init_data __initdata = {
- .table = msm_clocks_copper,
- .size = ARRAY_SIZE(msm_clocks_copper),
- .pre_init = msmcopper_clock_pre_init,
- .post_init = msmcopper_clock_post_init,
+struct clock_init_data msm8974_clock_init_data __initdata = {
+ .table = msm_clocks_8974,
+ .size = ARRAY_SIZE(msm_clocks_8974),
+ .pre_init = msm8974_clock_pre_init,
+ .post_init = msm8974_clock_post_init,
};
diff --git a/arch/arm/mach-msm/clock-local2.h b/arch/arm/mach-msm/clock-local2.h
index 547e633..1de79d7 100644
--- a/arch/arm/mach-msm/clock-local2.h
+++ b/arch/arm/mach-msm/clock-local2.h
@@ -174,5 +174,5 @@
extern struct clk_ops clk_ops_branch;
extern struct clk_ops clk_ops_vote;
-#endif /* __ARCH_ARM_MACH_MSM_COPPER_CLOCK_LOCAL_H */
+#endif /* __ARCH_ARM_MACH_MSM_CLOCK_LOCAL_2_H */
diff --git a/arch/arm/mach-msm/clock-pll.c b/arch/arm/mach-msm/clock-pll.c
index 49bb063..8c1f67e 100644
--- a/arch/arm/mach-msm/clock-pll.c
+++ b/arch/arm/mach-msm/clock-pll.c
@@ -248,7 +248,7 @@
#define PLL_LOCKED_BIT BIT(16)
-int copper_pll_clk_enable(struct clk *c)
+int msm8974_pll_clk_enable(struct clk *c)
{
unsigned long flags;
struct pll_clk *pll = to_pll_clk(c);
diff --git a/arch/arm/mach-msm/clock-pll.h b/arch/arm/mach-msm/clock-pll.h
index f24b066..90f8a95 100644
--- a/arch/arm/mach-msm/clock-pll.h
+++ b/arch/arm/mach-msm/clock-pll.h
@@ -111,7 +111,7 @@
}
int sr_pll_clk_enable(struct clk *c);
-int copper_pll_clk_enable(struct clk *c);
+int msm8974_pll_clk_enable(struct clk *c);
/*
* PLL vote clock APIs
diff --git a/arch/arm/mach-msm/clock.h b/arch/arm/mach-msm/clock.h
index 03d5790..51bfa67 100644
--- a/arch/arm/mach-msm/clock.h
+++ b/arch/arm/mach-msm/clock.h
@@ -172,7 +172,7 @@
extern struct clock_init_data qds8x50_clock_init_data;
extern struct clock_init_data msm8625_dummy_clock_init_data;
extern struct clock_init_data msm8930_clock_init_data;
-extern struct clock_init_data msmcopper_clock_init_data;
+extern struct clock_init_data msm8974_clock_init_data;
void msm_clock_init(struct clock_init_data *data);
int vote_vdd_level(struct clk_vdd_class *vdd_class, int level);
diff --git a/arch/arm/mach-msm/devices.h b/arch/arm/mach-msm/devices.h
index 152ca5b..d2fede2 100644
--- a/arch/arm/mach-msm/devices.h
+++ b/arch/arm/mach-msm/devices.h
@@ -373,8 +373,8 @@
extern struct platform_device mdm_8064_device;
extern struct platform_device msm_dsps_device_8064;
-extern struct platform_device *msm_copper_stub_regulator_devices[];
-extern int msm_copper_stub_regulator_devices_len;
+extern struct platform_device *msm_8974_stub_regulator_devices[];
+extern int msm_8974_stub_regulator_devices_len;
extern struct platform_device msm8960_cpu_idle_device;
extern struct platform_device msm8930_cpu_idle_device;
@@ -408,7 +408,7 @@
extern struct platform_device apq8064_cache_dump_device;
extern struct platform_device msm8930_cache_dump_device;
-extern struct platform_device copper_device_tz_log;
+extern struct platform_device msm8974_device_tz_log;
extern struct platform_device mdm_sglte_device;
diff --git a/arch/arm/mach-msm/gdsc.c b/arch/arm/mach-msm/gdsc.c
index f91e3dc..4665aec 100644
--- a/arch/arm/mach-msm/gdsc.c
+++ b/arch/arm/mach-msm/gdsc.c
@@ -197,4 +197,4 @@
module_exit(gdsc_exit);
MODULE_LICENSE("GPL v2");
-MODULE_DESCRIPTION("Copper GDSC power rail regulator driver");
+MODULE_DESCRIPTION("MSM8974 GDSC power rail regulator driver");
diff --git a/arch/arm/mach-msm/include/mach/board.h b/arch/arm/mach-msm/include/mach/board.h
index 460eefc..ef0b517 100644
--- a/arch/arm/mach-msm/include/mach/board.h
+++ b/arch/arm/mach-msm/include/mach/board.h
@@ -541,11 +541,11 @@
/* common init routines for use by arch/arm/mach-msm/board-*.c */
#ifdef CONFIG_OF_DEVICE
-void msm_copper_init(struct of_dev_auxdata **);
+void msm_8974_init(struct of_dev_auxdata **);
#endif
void msm_add_devices(void);
-void msm_copper_add_devices(void);
-void msm_copper_add_drivers(void);
+void msm_8974_add_devices(void);
+void msm_8974_add_drivers(void);
void msm_map_common_io(void);
void msm_map_qsd8x50_io(void);
void msm_map_msm8x60_io(void);
@@ -554,15 +554,15 @@
void msm_map_apq8064_io(void);
void msm_map_msm7x30_io(void);
void msm_map_fsm9xxx_io(void);
-void msm_map_copper_io(void);
+void msm_map_8974_io(void);
void msm_map_msm8625_io(void);
void msm_map_msm9625_io(void);
void msm_init_irq(void);
-void msm_copper_init_irq(void);
+void msm_8974_init_irq(void);
void vic_handle_irq(struct pt_regs *regs);
-void msm_copper_reserve(void);
-void msm_copper_very_early(void);
-void msm_copper_init_gpiomux(void);
+void msm_8974_reserve(void);
+void msm_8974_very_early(void);
+void msm_8974_init_gpiomux(void);
struct mmc_platform_data;
int msm_add_sdcc(unsigned int controller,
diff --git a/arch/arm/mach-msm/include/mach/irqs-copper.h b/arch/arm/mach-msm/include/mach/irqs-8974.h
similarity index 94%
rename from arch/arm/mach-msm/include/mach/irqs-copper.h
rename to arch/arm/mach-msm/include/mach/irqs-8974.h
index 8cd8620..d10b537 100644
--- a/arch/arm/mach-msm/include/mach/irqs-copper.h
+++ b/arch/arm/mach-msm/include/mach/irqs-8974.h
@@ -10,8 +10,8 @@
* GNU General Public License for more details.
*/
-#ifndef __ASM_ARCH_MSM_IRQS_COPPER_H
-#define __ASM_ARCH_MSM_IRQS_COPPER_H
+#ifndef __ASM_ARCH_MSM_IRQS_8974_H
+#define __ASM_ARCH_MSM_IRQS_8974_H
/* MSM ACPU Interrupt Numbers */
diff --git a/arch/arm/mach-msm/include/mach/irqs.h b/arch/arm/mach-msm/include/mach/irqs.h
index d630799..143159e 100644
--- a/arch/arm/mach-msm/include/mach/irqs.h
+++ b/arch/arm/mach-msm/include/mach/irqs.h
@@ -58,8 +58,8 @@
#else
-#if defined(CONFIG_ARCH_MSMCOPPER)
-#include "irqs-copper.h"
+#if defined(CONFIG_ARCH_MSM8974)
+#include "irqs-8974.h"
#elif defined(CONFIG_ARCH_MSM9615)
#include "irqs-9615.h"
#elif defined(CONFIG_ARCH_MSM9625)
diff --git a/arch/arm/mach-msm/include/mach/msm_bus_board.h b/arch/arm/mach-msm/include/mach/msm_bus_board.h
index 574491a..d95e4a4 100644
--- a/arch/arm/mach-msm/include/mach/msm_bus_board.h
+++ b/arch/arm/mach-msm/include/mach/msm_bus_board.h
@@ -83,13 +83,13 @@
extern struct msm_bus_fabric_registration msm_bus_8930_sys_fpb_pdata;
extern struct msm_bus_fabric_registration msm_bus_8930_cpss_fpb_pdata;
-extern struct msm_bus_fabric_registration msm_bus_copper_sys_noc_pdata;
-extern struct msm_bus_fabric_registration msm_bus_copper_mmss_noc_pdata;
-extern struct msm_bus_fabric_registration msm_bus_copper_bimc_pdata;
-extern struct msm_bus_fabric_registration msm_bus_copper_ocmem_noc_pdata;
-extern struct msm_bus_fabric_registration msm_bus_copper_periph_noc_pdata;
-extern struct msm_bus_fabric_registration msm_bus_copper_config_noc_pdata;
-extern struct msm_bus_fabric_registration msm_bus_copper_ocmem_vnoc_pdata;
+extern struct msm_bus_fabric_registration msm_bus_8974_sys_noc_pdata;
+extern struct msm_bus_fabric_registration msm_bus_8974_mmss_noc_pdata;
+extern struct msm_bus_fabric_registration msm_bus_8974_bimc_pdata;
+extern struct msm_bus_fabric_registration msm_bus_8974_ocmem_noc_pdata;
+extern struct msm_bus_fabric_registration msm_bus_8974_periph_noc_pdata;
+extern struct msm_bus_fabric_registration msm_bus_8974_config_noc_pdata;
+extern struct msm_bus_fabric_registration msm_bus_8974_ocmem_vnoc_pdata;
void msm_bus_rpm_set_mt_mask(void);
int msm_bus_board_rpm_get_il_ids(uint16_t *id);
diff --git a/arch/arm/mach-msm/include/mach/msm_iomap-copper.h b/arch/arm/mach-msm/include/mach/msm_iomap-8974.h
similarity index 66%
rename from arch/arm/mach-msm/include/mach/msm_iomap-copper.h
rename to arch/arm/mach-msm/include/mach/msm_iomap-8974.h
index 441f82a..fb61d54 100644
--- a/arch/arm/mach-msm/include/mach/msm_iomap-copper.h
+++ b/arch/arm/mach-msm/include/mach/msm_iomap-8974.h
@@ -11,8 +11,8 @@
* GNU General Public License for more details.
*/
-#ifndef __ASM_ARCH_MSM_IOMAP_COPPER_H
-#define __ASM_ARCH_MSM_IOMAP_COPPER_H
+#ifndef __ASM_ARCH_MSM_IOMAP_8974_H
+#define __ASM_ARCH_MSM_IOMAP_8974_H
/* Physical base address and size of peripherals.
* Ordered by the virtual base addresses they will be mapped at.
@@ -23,21 +23,21 @@
*
*/
-#define COPPER_MSM_SHARED_RAM_PHYS 0x0FA00000
+#define MSM8974_MSM_SHARED_RAM_PHYS 0x0FA00000
-#define COPPER_QGIC_DIST_PHYS 0xF9000000
-#define COPPER_QGIC_DIST_SIZE SZ_4K
+#define MSM8974_QGIC_DIST_PHYS 0xF9000000
+#define MSM8974_QGIC_DIST_SIZE SZ_4K
-#define COPPER_QGIC_CPU_PHYS 0xF9002000
-#define COPPER_QGIC_CPU_SIZE SZ_4K
+#define MSM8974_QGIC_CPU_PHYS 0xF9002000
+#define MSM8974_QGIC_CPU_SIZE SZ_4K
-#define COPPER_APCS_GCC_PHYS 0xF9011000
-#define COPPER_APCS_GCC_SIZE SZ_4K
+#define MSM8974_APCS_GCC_PHYS 0xF9011000
+#define MSM8974_APCS_GCC_SIZE SZ_4K
-#define COPPER_TLMM_PHYS 0xFD510000
-#define COPPER_TLMM_SIZE SZ_16K
+#define MSM8974_TLMM_PHYS 0xFD510000
+#define MSM8974_TLMM_SIZE SZ_16K
-#ifdef CONFIG_DEBUG_MSMCOPPER_UART
+#ifdef CONFIG_DEBUG_MSM8974_UART
#define MSM_DEBUG_UART_BASE IOMEM(0xFA71E000)
#define MSM_DEBUG_UART_PHYS 0xF991E000
#endif
diff --git a/arch/arm/mach-msm/include/mach/msm_iomap.h b/arch/arm/mach-msm/include/mach/msm_iomap.h
index 75cc43a..7085db7 100644
--- a/arch/arm/mach-msm/include/mach/msm_iomap.h
+++ b/arch/arm/mach-msm/include/mach/msm_iomap.h
@@ -50,7 +50,7 @@
#if defined(CONFIG_ARCH_MSM8960) || defined(CONFIG_ARCH_APQ8064) || \
defined(CONFIG_ARCH_MSM8930) || defined(CONFIG_ARCH_MSM9615) || \
- defined(CONFIG_ARCH_MSMCOPPER) || defined(CONFIG_ARCH_MSM7X27) || \
+ defined(CONFIG_ARCH_MSM8974) || defined(CONFIG_ARCH_MSM7X27) || \
defined(CONFIG_ARCH_MSM7X25) || defined(CONFIG_ARCH_MSM7X01A) || \
defined(CONFIG_ARCH_MSM8625) || defined(CONFIG_ARCH_MSM7X30) || \
defined(CONFIG_ARCH_MSM9625)
@@ -115,7 +115,7 @@
#include "msm_iomap-8930.h"
#include "msm_iomap-8064.h"
#include "msm_iomap-9615.h"
-#include "msm_iomap-copper.h"
+#include "msm_iomap-8974.h"
#include "msm_iomap-9625.h"
#else
diff --git a/arch/arm/mach-msm/include/mach/qdsp6v2/audio_acdb.h b/arch/arm/mach-msm/include/mach/qdsp6v2/audio_acdb.h
index 65cf647..3d33350 100644
--- a/arch/arm/mach-msm/include/mach/qdsp6v2/audio_acdb.h
+++ b/arch/arm/mach-msm/include/mach/qdsp6v2/audio_acdb.h
@@ -14,7 +14,7 @@
#define _AUDIO_ACDB_H
#include <linux/msm_audio_acdb.h>
-#ifdef CONFIG_ARCH_MSMCOPPER
+#ifdef CONFIG_ARCH_MSM8974
#include <sound/q6adm-v2.h>
#else
#include <sound/q6adm.h>
diff --git a/arch/arm/mach-msm/include/mach/rpm-regulator-copper.h b/arch/arm/mach-msm/include/mach/rpm-regulator-8974.h
similarity index 82%
rename from arch/arm/mach-msm/include/mach/rpm-regulator-copper.h
rename to arch/arm/mach-msm/include/mach/rpm-regulator-8974.h
index 2006ad3..07ae600 100644
--- a/arch/arm/mach-msm/include/mach/rpm-regulator-copper.h
+++ b/arch/arm/mach-msm/include/mach/rpm-regulator-8974.h
@@ -11,13 +11,13 @@
* GNU General Public License for more details.
*/
-#ifndef __ARCH_ARM_MACH_MSM_INCLUDE_MACH_RPM_REGULATOR_COPPER_H
-#define __ARCH_ARM_MACH_MSM_INCLUDE_MACH_RPM_REGULATOR_COPPER_H
+#ifndef __ARCH_ARM_MACH_MSM_INCLUDE_MACH_RPM_REGULATOR_8974_H
+#define __ARCH_ARM_MACH_MSM_INCLUDE_MACH_RPM_REGULATOR_8974_H
/**
* enum rpm_vreg_id - RPM regulator ID numbers (both real and pin control)
*/
-enum rpm_vreg_id_copper {
+enum rpm_vreg_id_8974 {
RPM_VREG_ID_PM8941_S1,
RPM_VREG_ID_PM8941_S2,
RPM_VREG_ID_PM8941_L12,
diff --git a/arch/arm/mach-msm/include/mach/rpm-regulator.h b/arch/arm/mach-msm/include/mach/rpm-regulator.h
index a010257..1f4ef2d 100644
--- a/arch/arm/mach-msm/include/mach/rpm-regulator.h
+++ b/arch/arm/mach-msm/include/mach/rpm-regulator.h
@@ -20,7 +20,7 @@
#include <mach/rpm-regulator-8660.h>
#include <mach/rpm-regulator-8960.h>
#include <mach/rpm-regulator-9615.h>
-#include <mach/rpm-regulator-copper.h>
+#include <mach/rpm-regulator-8974.h>
#include <mach/rpm-regulator-8930.h>
/**
diff --git a/arch/arm/mach-msm/include/mach/socinfo.h b/arch/arm/mach-msm/include/mach/socinfo.h
index c0ad65b..c0fe1bc 100644
--- a/arch/arm/mach-msm/include/mach/socinfo.h
+++ b/arch/arm/mach-msm/include/mach/socinfo.h
@@ -32,23 +32,23 @@
#define SOCINFO_VERSION_MINOR(ver) (ver & 0x0000ffff)
#ifdef CONFIG_OF
-#define early_machine_is_copper() \
- of_flat_dt_is_compatible(of_get_flat_dt_root(), "qcom,msmcopper")
-#define machine_is_copper() \
- of_machine_is_compatible("qcom,msmcopper")
-#define machine_is_copper_sim() \
- of_machine_is_compatible("qcom,msmcopper-sim")
-#define machine_is_copper_rumi() \
- of_machine_is_compatible("qcom,msmcopper-rumi")
+#define early_machine_is_msm8974() \
+ of_flat_dt_is_compatible(of_get_flat_dt_root(), "qcom,msm8974")
+#define machine_is_msm8974() \
+ of_machine_is_compatible("qcom,msm8974")
+#define machine_is_msm8974_sim() \
+ of_machine_is_compatible("qcom,msm8974-sim")
+#define machine_is_msm8974_rumi() \
+ of_machine_is_compatible("qcom,msm8974-rumi")
#define early_machine_is_msm9625() \
of_flat_dt_is_compatible(of_get_flat_dt_root(), "qcom,msm9625")
#define machine_is_msm9625() \
of_machine_is_compatible("qcom,msm9625")
#else
-#define early_machine_is_copper() 0
-#define machine_is_copper() 0
-#define machine_is_copper_sim() 0
-#define machine_is_copper_rumi() 0
+#define early_machine_is_msm8974() 0
+#define machine_is_msm8974() 0
+#define machine_is_msm8974_sim() 0
+#define machine_is_msm8974_rumi() 0
#define early_machine_is_msm9625() 0
#define machine_is_msm9625() 0
#endif
@@ -75,7 +75,7 @@
MSM_CPU_8930,
MSM_CPU_7X27AA,
MSM_CPU_9615,
- MSM_CPU_COPPER,
+ MSM_CPU_8974,
MSM_CPU_8627,
MSM_CPU_8625,
MSM_CPU_9625
diff --git a/arch/arm/mach-msm/io.c b/arch/arm/mach-msm/io.c
index e35d99b..a2f2c31 100644
--- a/arch/arm/mach-msm/io.c
+++ b/arch/arm/mach-msm/io.c
@@ -294,28 +294,28 @@
}
#endif /* CONFIG_ARCH_APQ8064 */
-#ifdef CONFIG_ARCH_MSMCOPPER
-static struct map_desc msm_copper_io_desc[] __initdata = {
- MSM_CHIP_DEVICE(QGIC_DIST, COPPER),
- MSM_CHIP_DEVICE(QGIC_CPU, COPPER),
- MSM_CHIP_DEVICE(APCS_GCC, COPPER),
- MSM_CHIP_DEVICE(TLMM, COPPER),
+#ifdef CONFIG_ARCH_MSM8974
+static struct map_desc msm_8974_io_desc[] __initdata = {
+ MSM_CHIP_DEVICE(QGIC_DIST, MSM8974),
+ MSM_CHIP_DEVICE(QGIC_CPU, MSM8974),
+ MSM_CHIP_DEVICE(APCS_GCC, MSM8974),
+ MSM_CHIP_DEVICE(TLMM, MSM8974),
{
.virtual = (unsigned long) MSM_SHARED_RAM_BASE,
.length = MSM_SHARED_RAM_SIZE,
.type = MT_DEVICE,
},
-#ifdef CONFIG_DEBUG_MSMCOPPER_UART
+#ifdef CONFIG_DEBUG_MSM8974_UART
MSM_DEVICE(DEBUG_UART),
#endif
};
-void __init msm_map_copper_io(void)
+void __init msm_map_8974_io(void)
{
- msm_shared_ram_phys = COPPER_MSM_SHARED_RAM_PHYS;
- msm_map_io(msm_copper_io_desc, ARRAY_SIZE(msm_copper_io_desc));
+ msm_shared_ram_phys = MSM8974_MSM_SHARED_RAM_PHYS;
+ msm_map_io(msm_8974_io_desc, ARRAY_SIZE(msm_8974_io_desc));
}
-#endif /* CONFIG_ARCH_MSMCOPPER */
+#endif /* CONFIG_ARCH_MSM8974 */
#ifdef CONFIG_ARCH_MSM7X30
static struct map_desc msm7x30_io_desc[] __initdata = {
diff --git a/arch/arm/mach-msm/msm_bus/Makefile b/arch/arm/mach-msm/msm_bus/Makefile
index 98e1250..ab62c20 100644
--- a/arch/arm/mach-msm/msm_bus/Makefile
+++ b/arch/arm/mach-msm/msm_bus/Makefile
@@ -8,5 +8,5 @@
obj-$(CONFIG_ARCH_MSM9615) += msm_bus_board_9615.o
obj-$(CONFIG_ARCH_APQ8064) += msm_bus_board_8064.o
obj-$(CONFIG_ARCH_MSM8930) += msm_bus_board_8930.o
-obj-$(CONFIG_ARCH_MSMCOPPER) += msm_bus_board_copper.o
+obj-$(CONFIG_ARCH_MSM8974) += msm_bus_board_8974.o
obj-$(CONFIG_DEBUG_FS) += msm_bus_dbg.o
diff --git a/arch/arm/mach-msm/msm_bus/msm_bus_board_copper.c b/arch/arm/mach-msm/msm_bus/msm_bus_board_8974.c
similarity index 98%
rename from arch/arm/mach-msm/msm_bus/msm_bus_board_copper.c
rename to arch/arm/mach-msm/msm_bus/msm_bus_board_8974.c
index 9858a73..265716d 100644
--- a/arch/arm/mach-msm/msm_bus/msm_bus_board_copper.c
+++ b/arch/arm/mach-msm/msm_bus/msm_bus_board_8974.c
@@ -25,9 +25,9 @@
#define NMASTERS 120
#define NSLAVES 150
-#define NFAB_COPPER 7
+#define NFAB_8974 7
-enum msm_bus_copper_master_ports_type {
+enum msm_bus_8974_master_ports_type {
/* System NOC Masters */
MASTER_PORT_LPASS_AHB = 0,
MASTER_PORT_QDSS_BAM,
@@ -99,7 +99,7 @@
MASTER_PORT_GW_SNOC_CNOC,
};
-enum msm_bus_copper_slave_ports_type {
+enum msm_bus_8974_slave_ports_type {
/* System NOC Slaves */
SLAVE_PORT_KMPSS = 1,
SLAVE_PORT_LPASS,
@@ -195,7 +195,7 @@
};
/* Hardware IDs for RPM */
-enum msm_bus_copper_mas_hw_id {
+enum msm_bus_8974_mas_hw_id {
MAS_APPSS_PROC = 0,
MAS_AMSS_PROC,
MAS_MNOC_BIMC,
@@ -256,7 +256,7 @@
MAS_SNOC_OVNOC,
};
-enum msm_bus_copper_slv_hw_id {
+enum msm_bus_8974_slv_hw_id {
SLV_EBI = 0,
SLV_APSS_L2,
SLV_BIMC_SNOC,
@@ -1863,7 +1863,7 @@
}
}
-static int msm_bus_board_copper_get_iid(int id)
+static int msm_bus_board_8974_get_iid(int id)
{
if ((id < SLAVE_ID_KEY && id >= NMASTERS) ||
id >= (SLAVE_ID_KEY + NSLAVES)) {
@@ -1881,12 +1881,12 @@
}
static struct msm_bus_board_algorithm msm_bus_board_algo = {
- .board_nfab = NFAB_COPPER,
- .get_iid = msm_bus_board_copper_get_iid,
+ .board_nfab = NFAB_8974,
+ .get_iid = msm_bus_board_8974_get_iid,
.assign_iids = msm_bus_board_assign_iids,
};
-struct msm_bus_fabric_registration msm_bus_copper_sys_noc_pdata = {
+struct msm_bus_fabric_registration msm_bus_8974_sys_noc_pdata = {
.id = MSM_BUS_FAB_SYS_NOC,
.name = "msm_sys_noc",
.info = sys_noc_info,
@@ -1903,7 +1903,7 @@
.rpm_enabled = 1,
};
-struct msm_bus_fabric_registration msm_bus_copper_mmss_noc_pdata = {
+struct msm_bus_fabric_registration msm_bus_8974_mmss_noc_pdata = {
.id = MSM_BUS_FAB_MMSS_NOC,
.name = "msm_mmss_noc",
.info = mmss_noc_info,
@@ -1920,7 +1920,7 @@
.rpm_enabled = 1,
};
-struct msm_bus_fabric_registration msm_bus_copper_bimc_pdata = {
+struct msm_bus_fabric_registration msm_bus_8974_bimc_pdata = {
.id = MSM_BUS_FAB_BIMC,
.name = "msm_bimc",
.info = bimc_info,
@@ -1937,7 +1937,7 @@
.rpm_enabled = 1,
};
-struct msm_bus_fabric_registration msm_bus_copper_ocmem_noc_pdata = {
+struct msm_bus_fabric_registration msm_bus_8974_ocmem_noc_pdata = {
.id = MSM_BUS_FAB_OCMEM_NOC,
.name = "msm_ocmem_noc",
.info = ocmem_noc_info,
@@ -1954,7 +1954,7 @@
.rpm_enabled = 1,
};
-struct msm_bus_fabric_registration msm_bus_copper_periph_noc_pdata = {
+struct msm_bus_fabric_registration msm_bus_8974_periph_noc_pdata = {
.id = MSM_BUS_FAB_PERIPH_NOC,
.name = "msm_periph_noc",
.info = periph_noc_info,
@@ -1970,7 +1970,7 @@
.rpm_enabled = 1,
};
-struct msm_bus_fabric_registration msm_bus_copper_config_noc_pdata = {
+struct msm_bus_fabric_registration msm_bus_8974_config_noc_pdata = {
.id = MSM_BUS_FAB_CONFIG_NOC,
.name = "msm_config_noc",
.info = config_noc_info,
@@ -1986,7 +1986,7 @@
.rpm_enabled = 1,
};
-struct msm_bus_fabric_registration msm_bus_copper_ocmem_vnoc_pdata = {
+struct msm_bus_fabric_registration msm_bus_8974_ocmem_vnoc_pdata = {
.id = MSM_BUS_FAB_OCMEM_VNOC,
.name = "msm_ocmem_vnoc",
.info = ocmem_vnoc_info,
diff --git a/arch/arm/mach-msm/platsmp.c b/arch/arm/mach-msm/platsmp.c
index 49e63aa..1e4301b 100644
--- a/arch/arm/mach-msm/platsmp.c
+++ b/arch/arm/mach-msm/platsmp.c
@@ -91,7 +91,7 @@
if (machine_is_apq8064_sim())
writel_relaxed(0xf0000, base_ptr+0x04);
- if (machine_is_copper_sim()) {
+ if (machine_is_msm8974_sim()) {
writel_relaxed(0x800, base_ptr+0x04);
writel_relaxed(0x3FFF, base_ptr+0x14);
}
@@ -139,7 +139,7 @@
machine_is_apq8064_sim())
return krait_release_secondary_sim(0x02088000, cpu);
- if (machine_is_copper_sim())
+ if (machine_is_msm8974_sim())
return krait_release_secondary_sim(0xf9088000, cpu);
if (cpu_is_msm8960() || cpu_is_msm8930() || cpu_is_apq8064())
diff --git a/arch/arm/mach-msm/pm-8x60.c b/arch/arm/mach-msm/pm-8x60.c
index 14e6f67..b74ebfb 100644
--- a/arch/arm/mach-msm/pm-8x60.c
+++ b/arch/arm/mach-msm/pm-8x60.c
@@ -568,7 +568,7 @@
static void msm_pm_qtimer_available(void)
{
- if (machine_is_copper())
+ if (machine_is_msm8974())
msm_pm_use_qtimer = true;
}
diff --git a/arch/arm/mach-msm/qdsp6v2/q6audio_common.h b/arch/arm/mach-msm/qdsp6v2/q6audio_common.h
index fc20847..e4291e7 100644
--- a/arch/arm/mach-msm/qdsp6v2/q6audio_common.h
+++ b/arch/arm/mach-msm/qdsp6v2/q6audio_common.h
@@ -15,7 +15,7 @@
#ifndef __Q6_AUDIO_COMMON_H__
#define __Q6_AUDIO_COMMON_H__
-#ifdef CONFIG_ARCH_MSMCOPPER
+#ifdef CONFIG_ARCH_MSM8974
#include <sound/apr_audio-v2.h>
#include <sound/q6asm-v2.h>
#else
diff --git a/arch/arm/mach-msm/rpm-smd.c b/arch/arm/mach-msm/rpm-smd.c
index 75f4d92..0edea3f 100644
--- a/arch/arm/mach-msm/rpm-smd.c
+++ b/arch/arm/mach-msm/rpm-smd.c
@@ -736,7 +736,7 @@
EXPORT_SYMBOL(msm_rpm_send_message_noirq);
static bool msm_rpm_set_standalone(void)
{
- if (machine_is_copper()) {
+ if (machine_is_msm8974()) {
pr_warn("%s(): Running in standalone mode, requests "
"will not be sent to RPM\n", __func__);
standalone = true;
diff --git a/arch/arm/mach-msm/socinfo.c b/arch/arm/mach-msm/socinfo.c
index 533e6cd..ede95b9 100644
--- a/arch/arm/mach-msm/socinfo.c
+++ b/arch/arm/mach-msm/socinfo.c
@@ -240,8 +240,8 @@
/* 8060A ID */
[124] = MSM_CPU_8960,
- /* Copper IDs */
- [126] = MSM_CPU_COPPER,
+ /* 8974 IDs */
+ [126] = MSM_CPU_8974,
/* 8625 IDs */
[127] = MSM_CPU_8625,
@@ -624,9 +624,9 @@
dummy_socinfo.id = 109;
else if (machine_is_msm9615_mtp() || machine_is_msm9615_cdp())
dummy_socinfo.id = 104;
- else if (early_machine_is_copper()) {
+ else if (early_machine_is_msm8974()) {
dummy_socinfo.id = 126;
- strlcpy(dummy_socinfo.build_id, "copper - ",
+ strlcpy(dummy_socinfo.build_id, "msm8974 - ",
sizeof(dummy_socinfo.build_id));
} else if (early_machine_is_msm9625()) {
dummy_socinfo.id = 134;
diff --git a/arch/arm/mach-msm/acpuclock-copper.c b/arch/arm/mach-msm/acpuclock-8974.c
similarity index 87%
rename from arch/arm/mach-msm/acpuclock-copper.c
rename to arch/arm/mach-msm/acpuclock-8974.c
index 7ba2e7d..2667a64 100644
--- a/arch/arm/mach-msm/acpuclock-copper.c
+++ b/arch/arm/mach-msm/acpuclock-8974.c
@@ -34,7 +34,7 @@
.m_offset = 0x08,
.n_offset = 0x0C,
.config_offset = 0x14,
/* TODO: Verify magic number for copper when available. */
.config_val = 0x7845C665,
.low_vdd_l_max = 52,
.vdd[HFPLL_VDD_NONE] = 0,
@@ -48,7 +48,7 @@
.m_offset = 0x08,
.n_offset = 0x0C,
.config_offset = 0x14,
/* TODO: Verify magic number for copper when available. */
.config_val = 0x7845C665,
.low_vdd_l_max = 52,
.vdd[HFPLL_VDD_NONE] = LVL_NONE,
@@ -113,7 +113,7 @@
.usecase = bw_level_tbl,
.num_usecases = ARRAY_SIZE(bw_level_tbl),
.active_only = 1,
- .name = "acpuclk-copper",
+ .name = "acpuclk-8974",
};
#define L2(x) (&l2_freq_tbl[(x)])
@@ -148,7 +148,7 @@
{ 0, { 0 } }
};
-static struct acpuclk_krait_params acpuclk_copper_params = {
+static struct acpuclk_krait_params acpuclk_8974_params = {
.scalable = scalable,
.pvs_acpu_freq_tbl[PVS_SLOW] = acpu_freq_tbl,
.pvs_acpu_freq_tbl[PVS_NOMINAL] = acpu_freq_tbl,
@@ -159,27 +159,27 @@
.qfprom_phys_base = 0xFC4A8000,
};
-static int __init acpuclk_copper_probe(struct platform_device *pdev)
+static int __init acpuclk_8974_probe(struct platform_device *pdev)
{
- return acpuclk_krait_init(&pdev->dev, &acpuclk_copper_params);
+ return acpuclk_krait_init(&pdev->dev, &acpuclk_8974_params);
}
-static struct of_device_id acpuclk_copper_match_table[] = {
- { .compatible = "qcom,acpuclk-copper" },
+static struct of_device_id acpuclk_8974_match_table[] = {
+ { .compatible = "qcom,acpuclk-8974" },
{}
};
-static struct platform_driver acpuclk_copper_driver = {
+static struct platform_driver acpuclk_8974_driver = {
.driver = {
- .name = "acpuclk-copper",
- .of_match_table = acpuclk_copper_match_table,
+ .name = "acpuclk-8974",
+ .of_match_table = acpuclk_8974_match_table,
.owner = THIS_MODULE,
},
};
-static int __init acpuclk_8960_init(void)
+static int __init acpuclk_8974_init(void)
{
- return platform_driver_probe(&acpuclk_copper_driver,
- acpuclk_copper_probe);
+ return platform_driver_probe(&acpuclk_8974_driver,
+ acpuclk_8974_probe);
}
-device_initcall(acpuclk_8960_init);
+device_initcall(acpuclk_8974_init);
@@ -34,7 +34,7 @@
.n_offset = 0x0C,
.config_offset = 0x14,
- /* TODO: Verify magic number for copper when available. */
+ /* TODO: Verify magic number for 8974 when available. */
.config_val = 0x7845C665,
.low_vdd_l_max = 52,
@@ -48,7 +48,7 @@
.n_offset = 0x0C,
.config_offset = 0x14,
- /* TODO: Verify magic number for copper when available. */
+ /* TODO: Verify magic number for 8974 when available. */
.config_val = 0x7845C665,
.low_vdd_l_max = 52,
diff --git a/arch/arm/mach-msm/msm_bus/msm_bus_fabric.c b/arch/arm/mach-msm/msm_bus/msm_bus_fabric.c
index a4b9b51..5d6653a 100644
--- a/arch/arm/mach-msm/msm_bus/msm_bus_fabric.c
+++ b/arch/arm/mach-msm/msm_bus/msm_bus_fabric.c
@@ -337,8 +337,8 @@
struct msm_bus_fabric *fabric = to_msm_bus_fabric(fabdev);
void *sel_cdata;
- /* Temporarily stub out arbitration settings for copper */
- if (machine_is_copper())
+ /* Temporarily stub out arbitration settings for msm8974 */
+ if (machine_is_msm8974())
return;
sel_cdata = fabric->cdata[ctx];